//===========================================================================
// Dreidimensionale Krper
//===========================================================================

//===========================================================================
// includes
//===========================================================================

// Deklaration einbinden
#include "cube.h"

// GL Bibliothek einbinden (je nach Betriebssystem)

#ifdef WIN32
    #include <windows.h>
    #include <GL/gl.h>
#else
    #include <OpenGL/gl.h>
#endif

#include <stdlib.h> // rand(), RAND_MAX


//===========================================================================
// implementierung
//===========================================================================

CCube::CCube()
{
    // Attribute mit Standardwerten initialisieren
    m_divisions    = 9;
    m_rotation     = 0.0f;
    m_rotationTime = 30.0f;
}


CCube::~CCube()
{
    // nichts aufzurumen
}


void CCube::update(float time)
{
    // Rotation des Objekls weiterbewegen (in Grad)
    m_rotation += 360.0f * time / m_rotationTime;
}


void CCube::render()
{
    // Krper rotieren
    glMatrixMode(GL_MODELVIEW);
    glPushMatrix();
    glRotatef(m_rotation, 0.0f, 1.0f, 0.0f);

    // Linienzeichnen einleiten
    glBegin(GL_LINES);

    // Verschachtelte For-Schleifen, um das Rechteck
    // mit einer bestimmten Anzahl an Unterteiolungen
    // zu druchlaufen
    for (unsigned int j = 0; j <= m_divisions; j++)
    {
        // Unterteilungspunkt b zwischen -1 und 1 berechnen
        float b = float(j)/float(m_divisions)*2.0f - 1.0f;

        for (unsigned int i = 0; i <= m_divisions; i++)
        {
            // Unterteilungspunkt a zwischen -1 und 1 berechnen
            float a = float(i)/float(m_divisions)*2.0f - 1.0f;

            // Linie in x-Richtung zeichnen
            glVertex3f(-1, a, b);
            glVertex3f( 1, a, b);

            // Linie in y-Richtung zeichnen
            glVertex3f(a, -1, b);
            glVertex3f(a,  1, b);

            // Linie in z-Richtung zeichnen
            glVertex3f(a, b, -1);
            glVertex3f(a, b,  1);
        }
    }

    // Ende der Linien
    glEnd();

    // Alte Transformation wiederherstellen (Rotation lschen)
    glPopMatrix();

} // render()
